@@ -1,13 +1,11 @@
 #!/usr/bin/env python3
 
 import sys
-import time
 import random
 import argparse
-from tqdm import tqdm
 from datetime import datetime
 from googlesearch import search
-
+                       
 
 colors = True
 machine = sys.platform # Detecting the os of current system
@@ -23,19 +21,6 @@ else:
     yellow = "\x1b[93m"
 
 
-banner = f"""{red}
-╭━━━╮╱╱╭╮╱╱╱╭╮
-┃╭━╮┣┳┳╯┣━┳┳┫┣╮
-┃┃┃┃┣┃┫╋┃╋┃╭┫━┫
-┃┃┃┃┣┻┻━┻━┻╯╰┻╯
-┃╰━╯┃
-Disclaimer{white}:
-This tool was developed for educational purposes and should not be used in environments
-without {red}legal authorization{white}.
-Therefore, the author shall {red}not{white} be responsible for the damages that might be done with it.{end}
-"""
-
-
 user_agents = ("Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/14.1.1 Safari/605.1.15",
                            "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:90.0) Gecko/20100101 Firefox/90.0",
                            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.107 Safari/537.36 Edg/92.0.902.55",
@@ -66,55 +51,50 @@ user_agents = ("Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.
                            "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.114 Safari/537.36",
                            "Mozilla/5.0 (Macintosh; Intel Mac OS X 11_0_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.198 Safari/537.36",
                            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.107 Safari/537.36/swoLZb83-26")
-                           
+
 
 def dork():
     start = datetime.now()
-    parser = argparse.ArgumentParser(description=f"""{red}ox{white}Dork (Google dorking tool) : OXDORK uses Google dorking techniques and Google dorks to find security holes and misconfigurations in web servers. || {red}https://github.com/{white}rlyonheart{end}""")
-    parser.add_argument("query", help=f"{white}search query{end}")
-    parser.add_argument("-c","--count",help=f"{white}number of results to return ({yellow}default is 50{white}){end}",dest="count", metavar="NUMBER", default=50)
-    parser.add_argument("-o","--outfile",help=f"{white}write results to a file{end}",dest="output", metavar="FILENAME")
-    parser.add_argument("-v", "--verbose", help=f"{white}run {red}oxdork{white} in verbose mode{end}", dest="verbose", action="store_true")
+    parser = argparse.ArgumentParser(description=f"{green}ox{white}Dork (Google dorking tool) : OXDORK uses Google dorking techniques and Google dorks to find security holes and misconfigurations in web servers. {green}Developed by{white} Richard Mwewa | {green}https://github.com/{white}rlyonheart{end}")
+    parser.add_argument("query", help=f"{white}query; {red}Note{white} if query contains spaces, put it inside {green}quote symbols{end}")
+    parser.add_argument("-c","--count",help=f"{green}number{white} of results to return ({green}default is 50{white}){end}",dest="count", metavar=f"{white}NUMBER{end}", default=50)
+    parser.add_argument("-o","--outfile",help=f"{white}write output to a specified {green}file{end}",dest="output", metavar=f"{white}FILENAME{end}")
+    parser.add_argument("-v", "--verbose", help=f"{white}run oxdork in {green}verbose{white} mode{end}", dest="verbose", action="store_true")
     args = parser.parse_args()
     number = 0
     counter = 0
     if args.verbose:
-    	print(banner)
-    	print(f"{white}* Fetching dorks [query={green}{args.query}{white}] [dorks_count={red}{args.count}{end}{white}]...{end}")
+    	print(f"{white}* Started Oxdork v2021.2.1.6 (https://pypi.org/project/oxdork) at {green}{start}{end}")
+    	print(f"\n{white}{args.query}\n├ Status: fetching {green}{args.count}{white} dorks...")
     while True:
         try:
-        	google_search = search(args.query, num=int(args.count),start=0,stop=None,lang="en",tld="com", pause=2.5,
-        	user_agent=f"{random.choice(user_agents)}")
-        	for result in tqdm(google_search):
+        	for result in search(args.query, num=int(args.count),start=0,stop=None,lang="en",tld="com", pause=2.5,user_agent=f"{random.choice(user_agents)}"):
         		counter+=1
-        		print(f"{white}[{counter}] oxdork:: [query={green}{args.query}{white}] {green}{result}{end}")
+        		print(f"{white}├─ {counter}: {green}{result}{end}")
         		if args.output:
         			output(args,result)
-        			
-        		time.sleep(0.05)
+
         		number += 1
         		if number >= int(args.count):
         		    break
         	if args.verbose:
-        		exit(f"{white}* Stopped [seconds={red}{datetime.now()-start}{white}]{end}")
+        		exit(f"{white}└╼ Oxdork stopped in {green}{datetime.now()-start}{white} seconds.{end}")
         	break
         except KeyboardInterrupt:
         	if args.verbose:
-        		exit(f"{white}* Process interrupted [{red}Ctrl{white}+{red}C{white}].{end}")
+        		exit(f"{white}└╼ Oxdork interrupted with {red}Ctrl{white}+{red}C{end}")
         	break
         
         except Exception as e:
         	if args.verbose:
-        		print(f"{white}* Error [query={red}{args.query}{white}]: {red}{e}{end}")
-        		print(f"{white}* Retrying [query={green}{args.query}{white}]...{end}")
+        		print(f"{white}├ Error: {red}{e}{end}")
+        		print(f"{white}├─ Status: {green}Retrying...{end}")
         		
         		
 def output(args,result):
     with open(args.output, "a") as file:
     	file.write(f"{result}\n")
     	file.close()
-    	if args.verbose:
-    		print(f"{white}* result(s) written to ./{red}{args.output}{end}")		
 
 if __name__ == "__main__":
 	dork()
\ No newline at end of file
